@@ -45,7 +45,7 @@ class DesiredCapabilities(object):
 
     SAFARI = {
         "browserName": "safari",
-        "version": "5",
+        "version": "",
         "platform": "MAC",
         "javascriptEnabled": True,
     }
@@ -83,3 +83,11 @@ class DesiredCapabilities(object):
         "platform": "ANDROID",
         "javascriptEnabled": True,
     }
+    
+    PHANTOMJS = {
+        "browserName":"phantomjs",
+        "version": "",
+        "platform": "ANY",
+        "javascriptEnabled": True,
+    }
+
