@@ -5,13 +5,13 @@ class ProxyTypeFactory:
 
 class ProxyType:
 
-    DIRECT = ProxyTypeFactory.make(0, 'direct')           # Direct connection, no proxy (default on Windows).
-    MANUAL = ProxyTypeFactory.make(1, 'manual')           # Manual proxy settings (e.g., for httpProxy).
-    PAC = ProxyTypeFactory.make(2, 'pac')                 # Proxy autoconfiguration from URL.
-    RESERVED_1 = ProxyTypeFactory.make(3, 'reserved1')    # Never used.
-    AUTODETECT = ProxyTypeFactory.make(4, 'autodetect')   # Proxy autodetection (presumably with WPAD).
-    SYSTEM = ProxyTypeFactory.make(5, 'system')           # Use system settings (default on Linux).
-    UNSPECIFIED = ProxyTypeFactory.make(6, 'unspecified')
+    DIRECT = ProxyTypeFactory.make(0, 'DIRECT')           # Direct connection, no proxy (default on Windows).
+    MANUAL = ProxyTypeFactory.make(1, 'MANUAL')           # Manual proxy settings (e.g., for httpProxy).
+    PAC = ProxyTypeFactory.make(2, 'PAC')                 # Proxy autoconfiguration from URL.
+    RESERVED_1 = ProxyTypeFactory.make(3, 'RESERVED1')    # Never used.
+    AUTODETECT = ProxyTypeFactory.make(4, 'AUTODETECT')   # Proxy autodetection (presumably with WPAD).
+    SYSTEM = ProxyTypeFactory.make(5, 'SYSTEM')           # Use system settings (default on Linux).
+    UNSPECIFIED = ProxyTypeFactory.make(6, 'UNSPECIFIED')
 
 
 class Proxy(object):
@@ -26,19 +26,19 @@ class Proxy(object):
 
     def __init__(self, raw=None):
         if raw is not None:
-            if raw.has_key('proxyType') and raw['proxyType'] is not None:
+            if 'proxyType' in raw and raw['proxyType'] is not None:
                 self.proxy_type = raw['proxyType']
-            if raw.has_key('ftpProxy') and raw['ftpProxy'] is not None:
+            if 'ftpProxy' in raw and raw['ftpProxy'] is not None:
                 self.ftp_proxy = raw['ftpProxy']
-            if raw.has_key('httpProxy') and raw['httpProxy'] is not None:
+            if 'httpProxy' in raw and raw['httpProxy'] is not None:
                 self.http_proxy = raw['httpProxy']
-            if raw.has_key('noProxy') and raw['noProxy'] is not None:
+            if 'noProxy' in raw and raw['noProxy'] is not None:
                 self.no_proxy = raw['noProxy']
-            if raw.has_key('proxyAutoconfigUrl') and raw['proxyAutoconfigUrl'] is not None:
+            if 'proxyAutoconfigUrl' in raw and raw['proxyAutoconfigUrl'] is not None:
                 self.proxy_autoconfig_url = raw['proxyAutoconfigUrl']
-            if raw.has_key('sslProxy') and raw['sslProxy'] is not None:
+            if 'sslProxy' in raw and raw['sslProxy'] is not None:
                 self.sslProxy = raw['sslProxy']
-            if raw.has_key('autodetect') and raw['autodetect'] is not None:
+            if 'autodetect' in raw and raw['autodetect'] is not None:
                 self.auto_detect = raw['autodetect']
 
     @property
@@ -57,12 +57,10 @@ class Proxy(object):
     @auto_detect.setter
     def auto_detect(self, value):
         if isinstance(value, bool):
-            if self.autodetect is value:
-                return
-            self._verify_proxy_type_compatilibily(ProxyType.AUTODETECT)
-            self.proxyType = ProxyType.AUTODETECT
-            self.autodetect = value
-            return self
+            if self.autodetect is not value:
+                self._verify_proxy_type_compatilibily(ProxyType.AUTODETECT)
+                self.proxyType = ProxyType.AUTODETECT
+                self.autodetect = value
         else:
             raise ValueError("value needs to be a boolean")
 
@@ -113,7 +111,7 @@ class Proxy(object):
     @ssl_proxy.setter
     def ssl_proxy(self, value):
         self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
-        self.proxyType = value
+        self.proxyType = ProxyType.MANUAL
         self.sslProxy = value
 
     def _verify_proxy_type_compatilibily(self, compatibleProxy):
